@@ -32,12 +32,14 @@ typedef struct
 	int nBrightness;
 	int nDeblock_Y;
 	int nDeblock_UV;
-	int nDering;
+	int nDering_Y;
+	int nDering_UV;
 	int nFilmEffect;
 	int nFlipVideo;
 	int nForceColorspace;
 	unsigned int supported_4cc;
 	int videoinfo_compat;
+	int aspect_ratio;
 } CONFIG;
 
 
@@ -56,4 +58,5 @@ BOOL CALLBACK adv_proc(HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lParam);
 #endif
 
 
-#endif
\ No newline at end of file
+#endif
+
